<!-- markdownlint-disable MD041 -->

```{toctree}
---
hidden:
glob:
caption: API
---
api/*
```

```{toctree}
---
hidden:
caption: Index
---
genindex
modindex
search
```

```{include} ../README.md
---
relative-docs: docs
---
```
